@@ -25,10 +25,12 @@ def updated_setup(
 ) -> str:
     if dependencies:
         try:
-            old_dependencies_str = old_setup.split('install_requires')[-1].split('[')[1].split(']')[0]
+            old_dependencies_str = 'install_requires{}'.format(old_setup.split('install_requires')[-1].split(']')[0])
 
-            if old_dependencies_str:
-                old_setup = old_setup.replace(old_dependencies_str, __dependencies_str(dependencies))
+            old_setup = old_setup.replace(
+                old_dependencies_str,
+                'install_requires=[{}'.format(__dependencies_str(dependencies))
+            )
         except Exception as e:
             print(e)
 
@@ -105,7 +107,9 @@ def __get_python_classifiers(
 def __dependencies_str(dependencies: List[InstalledPackage]) -> str:
     return '\n{}{}\n{}'.format(
         8*' ',
-        ',\n{}'.format(8*' ').join(['\'{}\''.format(d.get_install_name()) for d in dependencies]),
+        ',\n{}'.format(8*' ').join(
+            ['\'{}{}\''.format(d.get_install_name(), '>={}'.format(d.version) if not d.private else '') for d in dependencies]
+        ),
         4*' '
     ) if dependencies else ''
 
